Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3)

Unified Diff: pkg/third_party/html5lib/test/parser_test.dart

Issue 23540004: Remove use of dart:json from third_party. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/third_party/html5lib/test/tokenizer_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/third_party/html5lib/test/parser_test.dart
diff --git a/pkg/third_party/html5lib/test/parser_test.dart b/pkg/third_party/html5lib/test/parser_test.dart
index 01256347dd9eb9f5424e5f394b27604cc527dcb3..ba1ea3ef706bc287d4fafa846f8ee71de92f62ea 100644
--- a/pkg/third_party/html5lib/test/parser_test.dart
+++ b/pkg/third_party/html5lib/test/parser_test.dart
@@ -1,7 +1,7 @@
library parser_test;
+import 'dart:convert;
import 'dart:io';
-import 'dart:json' as json;
import 'package:path/path.dart' as pathos;
import 'package:unittest/unittest.dart';
import 'package:html5lib/dom.dart';
@@ -114,11 +114,11 @@ void main() {
/** Extract the name for the test based on the test input data. */
_nameFor(String input) {
// Using json.parse to unescape other unicode characters
var escapeQuote = input
.replaceAll(new RegExp('\\\\.'), '_')
.replaceAll(new RegExp('\u0000'), '_')
.replaceAll('"', '\\"')
.replaceAll(new RegExp('[\n\r\t]'),'_');
- return json.parse('"$escapeQuote"');
+ return JSON.decode('"$escapeQuote"');
}
« no previous file with comments | « no previous file | pkg/third_party/html5lib/test/tokenizer_test.dart » ('j') | no next file with comments »
@@ -114,11 +114,11 @@ void main() {
/** Extract the name for the test based on the test input data. */
_nameFor(String input) {
- // Using json.parse to unescape other unicode characters
+ // Using JSON.decode to unescape other unicode characters
var escapeQuote = input
.replaceAll(new RegExp('\\\\.'), '_')

Powered by Google App Engine
This is Rietveld 408576698